@@ -9,7 +9,7 @@ from tracardi_fullcontact_webhook.plugin import FullContactAction
 
 init = {
     "source": {
-        "id": "bfccef2e-2f67-472b-82dc-ad3b53636217"
+        "id": "f634f001-2580-4b2e-a7bb-df099ba9afbd"
     },
     "pii": {
         "email": "kazi@gmail.com"
@@ -23,8 +23,8 @@ event = Event(id="event-id",
               session=Session(id="session-id"),
               source=Entity(id="source-id"),
               context=Context())
-result = run_plugin(FullContactAction, init, payload,
-                    profile)
+
+result = run_plugin(FullContactAction, init, payload, profile)
 
 print("OUTPUT:", result.output)
 print("PROFILE:", result.profile)
